@@ -3,7 +3,7 @@
 void Writer::srTables() const
 {
     *d_out << "\n"
-        "// State info and SR__ transitions for each state.\n"
+        "// State info and SR_ transitions for each state.\n"
         "\n";
 
     TableSupport support;
@@ -20,7 +20,7 @@ void Writer::srTables() const
         State::begin(), State::end(),
         [&](State const *state)
         {
-            srTable(state, d_baseclass, table, *d_out);
+            srTable(state, table, *d_out);
         }
     );
 
